@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlBinary.h,v 1.13 2004/04/14 23:16:31 robux4 Exp $
+	\version \$Id: EbmlBinary.h 1065 2005-02-05 21:30:28Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 	\author Julien Coloos	<suiryc @ users.sf.net>
 */
@@ -62,9 +62,9 @@ class EBML_DLL_API EbmlBinary : public EbmlElement {
 		EbmlBinary(const EbmlBinary & ElementToClone);
 		virtual ~EbmlBinary(void);
 	
-		uint32 RenderData(IOCallback & output, bool bForceRender, bool bSaveDefault = false);
+		uint32 RenderData(IOCallback & output, bool bForceRender, bool bKeepIntact = false);
 		uint64 ReadData(IOCallback & input, ScopeMode ReadFully = SCOPE_ALL_DATA);
-		uint64 UpdateSize(bool bSaveDefault = false, bool bForceRender = false);
+		uint64 UpdateSize(bool bKeepIntact = false, bool bForceRender = false);
 	
 		void SetBuffer(const binary *Buffer, const uint32 BufferSize) {
 			Data = (binary *) Buffer;
@@ -76,8 +76,8 @@ class EBML_DLL_API EbmlBinary : public EbmlElement {
 		
 		void CopyBuffer(const binary *Buffer, const uint32 BufferSize) {
 			if (Data != NULL)
-				delete Data;
-			Data = new binary[BufferSize];
+				free(Data);
+			Data = (binary *)malloc(BufferSize * sizeof(binary));
 			memcpy(Data, Buffer, BufferSize);
 			Size = BufferSize;
 			bValueIsSet = true;
@@ -90,6 +90,8 @@ class EBML_DLL_API EbmlBinary : public EbmlElement {
 			return false;
 		}
 
+		bool operator==(const EbmlBinary & ElementToCompare);
+
 	protected:
 		binary *Data; // the binary data inside the element
 };
