@@ -28,7 +28,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlElement.h,v 1.14 2004/04/14 23:16:31 robux4 Exp $
+	\version \$Id: EbmlElement.h 1033 2005-01-10 22:49:42Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #ifndef LIBEBML_ELEMENT_H
@@ -182,12 +182,12 @@ class EBML_DLL_API EbmlElement {
 
 		uint64 GetElementPosition() const {return ElementPosition;}
 
-		uint64 ElementSize(bool bSaveDefault = false) const; /// return the size of the header+data
+		uint64 ElementSize(bool bKeepIntact = false) const; /// return the size of the header+data, before writing
 		
-		uint32 Render(IOCallback & output, bool bSaveDefault = false, bool bKeepPosition = false, bool bForceRender = false);
+		uint32 Render(IOCallback & output, bool bKeepIntact = false, bool bKeepPosition = false, bool bForceRender = false);
 
-		virtual uint64 UpdateSize(bool bSaveDefault = false, bool bForceRender = false) = 0; /// update the Size of the Data stored
-		virtual uint64 GetSize() const {return Size;}
+		virtual uint64 UpdateSize(bool bKeepIntact = false, bool bForceRender = false) = 0; /// update the Size of the Data stored
+		virtual uint64 GetSize() const {return Size;} /// return the size of the data stored in the element, on reading
 
 		virtual uint64 ReadData(IOCallback & input, ScopeMode ReadFully = SCOPE_ALL_DATA) = 0;
 		virtual void Read(EbmlStream & inDataStream, const EbmlSemanticContext & Context, int & UpperEltFound, EbmlElement * & FoundElt, bool AllowDummyElt = false, ScopeMode ReadFully = SCOPE_ALL_DATA);
@@ -210,7 +210,7 @@ class EBML_DLL_API EbmlElement {
 		virtual bool IsDummy() const {return false;}
 		virtual bool IsMaster() const {return false;}
 
-		uint8 HeadSize() const {return EbmlId(*this).Length + CodedSizeLength(Size, SizeLength);}
+		uint8 HeadSize() const {return EbmlId(*this).Length + CodedSizeLength(Size, SizeLength);} /// return the size of the head, on reading/writing
 		
 		/*!
 			\brief Force the size of an element
@@ -223,7 +223,7 @@ class EBML_DLL_API EbmlElement {
 		/*!
 			\brief void the content of the element (replace by EbmlVoid)
 		*/
-		uint32 VoidMe(IOCallback & output, bool bSaveDefault = false);
+		uint32 VoidMe(IOCallback & output, bool bKeepIntact = false);
 
 		bool DefaultISset() const {return DefaultIsSet;}
 		virtual bool IsDefaultValue() const = 0;
@@ -253,13 +253,13 @@ class EBML_DLL_API EbmlElement {
 		*/
 		static EbmlElement *CreateElementUsingContext(const EbmlId & aID, const EbmlSemanticContext & Context, int & LowLevel, bool IsGlobalContext, bool bAllowDummy = false, unsigned int MaxLowerLevel = 1);
 
-		uint32 RenderHead(IOCallback & output, bool bForceRender, bool bSaveDefault = false, bool bKeepPosition = false);
+		uint32 RenderHead(IOCallback & output, bool bForceRender, bool bKeepIntact = false, bool bKeepPosition = false);
 		uint32 MakeRenderHead(IOCallback & output, bool bKeepPosition);
 	
 		/*!
 			\brief prepare the data before writing them (in case it's not already done by default)
 		*/
-		virtual uint32 RenderData(IOCallback & output, bool bForceRender, bool bSaveDefault = false) = 0;
+		virtual uint32 RenderData(IOCallback & output, bool bForceRender, bool bKeepIntact = false) = 0;
 
 		/*!
 			\brief special constructor for cloning
