@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlFloat.h 639 2004-07-09 20:59:14Z mosu $
+	\version \$Id: EbmlFloat.h 1033 2005-01-10 22:49:42Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #ifndef LIBEBML_FLOAT_H
@@ -50,9 +50,6 @@ class EBML_DLL_API EbmlFloat : public EbmlElement {
 		enum Precision {
 			 FLOAT_32
 			,FLOAT_64
-#if LIBEBML_SUPPORT_FLOAT80
-			,FLOAT_80
-#endif // LIBEBML_SUPPORT_FLOAT80
 		};
 
 		EbmlFloat(const Precision prec = FLOAT_32);
@@ -61,25 +58,17 @@ class EBML_DLL_API EbmlFloat : public EbmlElement {
 
 		bool ValidateSize() const 
 		{
-			return (Size == 4 || Size == 8
-#if LIBEBML_SUPPORT_FLOAT80
-			|| Size == 10
-#endif // LIBEBML_SUPPORT_FLOAT80
-				);
+			return (Size == 4 || Size == 8);
 		}
 	
-		uint32 RenderData(IOCallback & output, bool bForceRender, bool bSaveDefault = false);
+		uint32 RenderData(IOCallback & output, bool bForceRender, bool bKeepIntact = false);
 		uint64 ReadData(IOCallback & input, ScopeMode ReadFully = SCOPE_ALL_DATA);
-		uint64 UpdateSize(bool bSaveDefault = false, bool bForceRender = false);
+		uint64 UpdateSize(bool bKeepIntact = false, bool bForceRender = false);
 
 		void SetPrecision(const EbmlFloat::Precision prec = FLOAT_32) 
 		{
 			if (prec == FLOAT_64)
 				Size = 8;
-#if LIBEBML_SUPPORT_FLOAT80
-			else if (prec == FLOAT_80)
-				Size = 10;
-#endif // LIBEBML_SUPPORT_FLOAT80
 			else
 				Size = 4; // default size
 		}
