@@ -28,7 +28,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlDate.cpp 639 2004-07-09 20:59:14Z mosu $
+	\version \$Id: EbmlDate.cpp 1033 2005-01-10 22:49:42Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #include <cassert>
@@ -65,7 +65,7 @@ uint64 EbmlDate::ReadData(IOCallback & input, ScopeMode ReadFully)
 	return Size;
 }
 
-uint32 EbmlDate::RenderData(IOCallback & output, bool bForceRender, bool bSaveDefault)
+uint32 EbmlDate::RenderData(IOCallback & output, bool bForceRender, bool bKeepIntact)
 {
 	if (Size != 0) {
 		assert(Size == 8);
