@@ -28,7 +28,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlElement.cpp 639 2004-07-09 20:59:14Z mosu $
+	\version \$Id: EbmlElement.cpp 1033 2005-01-10 22:49:42Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 
@@ -529,19 +529,19 @@ EbmlElement *EbmlElement::CreateElementUsingContext(const EbmlId & aID, const Eb
 /*!
 	\todo verify that the size written is the same as the data written
 */
-uint32 EbmlElement::Render(IOCallback & output, bool bSaveDefault, bool bKeepPosition, bool bForceRender)
+uint32 EbmlElement::Render(IOCallback & output, bool bKeepIntact, bool bKeepPosition, bool bForceRender)
 {
-	assert(bValueIsSet); // an element is been rendered without a value set !!!
+	assert(bValueIsSet || (bKeepIntact && DefaultISset())); // an element is been rendered without a value set !!!
 		                 // it may be a mandatory element without a default value
 	try {
-		if (!bSaveDefault && IsDefaultValue()) {
+		if (!bKeepIntact && IsDefaultValue()) {
 			return 0;
 		}
 #if defined(_DEBUG) || defined(DEBUG)
-		uint64 SupposedSize = UpdateSize(bSaveDefault, bForceRender);
+		uint64 SupposedSize = UpdateSize(bKeepIntact, bForceRender);
 #endif // _DEBUG
-		uint32 result = RenderHead(output, bForceRender, bSaveDefault, bKeepPosition);
-		uint64 WrittenSize = RenderData(output, bForceRender, bSaveDefault);
+		uint32 result = RenderHead(output, bForceRender, bKeepIntact, bKeepPosition);
+		uint64 WrittenSize = RenderData(output, bForceRender, bKeepIntact);
 #if defined(_DEBUG) || defined(DEBUG)
 	if (SupposedSize != (0-1)) assert(WrittenSize == SupposedSize);
 #endif // DEBUG
@@ -559,12 +559,12 @@ uint32 EbmlElement::Render(IOCallback & output, bool bSaveDefault, bool bKeepPos
 	\todo handle exceptions on errors
 	\todo handle CodeSize bigger than 5 bytes
 */
-uint32 EbmlElement::RenderHead(IOCallback & output, bool bForceRender, bool bSaveDefault, bool bKeepPosition)
+uint32 EbmlElement::RenderHead(IOCallback & output, bool bForceRender, bool bKeepIntact, bool bKeepPosition)
 {
 	if (EbmlId(*this).Length <= 0 || EbmlId(*this).Length > 4)
 		return 0;
 	
-	UpdateSize(bSaveDefault, bForceRender);
+	UpdateSize(bKeepIntact, bForceRender);
 	
 	return MakeRenderHead(output, bKeepPosition);
 }
@@ -590,9 +590,9 @@ uint32 EbmlElement::MakeRenderHead(IOCallback & output, bool bKeepPosition)
 	return FinalHeadSize;
 }
 
-uint64 EbmlElement::ElementSize(bool bSaveDefault) const
+uint64 EbmlElement::ElementSize(bool bKeepIntact) const
 {
-	if (!bSaveDefault && IsDefaultValue())
+	if (!bKeepIntact && IsDefaultValue())
 		return 0; // won't be saved
 	return Size + EbmlId(*this).Length + CodedSizeLength(Size, SizeLength);
 }
@@ -643,14 +643,14 @@ uint32 EbmlElement::OverwriteHead(IOCallback & output, bool bKeepPosition)
 	return Result;
 }
 
-uint32 EbmlElement::VoidMe(IOCallback & output, bool bSaveDefault)
+uint32 EbmlElement::VoidMe(IOCallback & output, bool bKeepIntact)
 {
 	if (ElementPosition == 0) {
 		return 0; // the element has not been written
 	}
 
 	EbmlVoid Dummy;
-	return Dummy.Overwrite(*this, output, bSaveDefault);
+	return Dummy.Overwrite(*this, output, bKeepIntact);
 }
 
 END_LIBEBML_NAMESPACE
