@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlFloat.cpp 639 2004-07-09 20:59:14Z mosu $
+	\version \$Id: EbmlFloat.cpp 1033 2005-01-10 22:49:42Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 
@@ -64,13 +64,9 @@ EbmlFloat::EbmlFloat(const EbmlFloat & ElementToClone)
 	\todo handle exception on errors
 	\todo handle 10 bits precision
 */
-uint32 EbmlFloat::RenderData(IOCallback & output, bool bForceRender, bool bSaveDefault)
+uint32 EbmlFloat::RenderData(IOCallback & output, bool bForceRender, bool bKeepIntact)
 {
-#if LIBEBML_SUPPORT_FLOAT80
-	assert(Size == 4 || Size == 8 || Size == 10);
-#else // LIBEBML_SUPPORT_FLOAT80
 	assert(Size == 4 || Size == 8);
-#endif // LIBEBML_SUPPORT_FLOAT80
 
 	if (Size == 4) {
 		float val = Value;
@@ -81,21 +77,13 @@ uint32 EbmlFloat::RenderData(IOCallback & output, bool bForceRender, bool bSaveD
 		big_int64 TmpToWrite(*((int64 *) &val));
 		output.writeFully(&TmpToWrite.endian(), Size);
 	} 
-#if LIBEBML_SUPPORT_FLOAT80
-	else {
-		long double val = Value;
-		assert(sizeof(long double) == 10);
-		big_80bits TmpToWrite(*((bits80 *) &val));
-		output.writeFully(&TmpToWrite.endian(), Size);
-	}
-#endif // LIBEBML_SUPPORT_FLOAT80
 
 	return Size;
 }
 
-uint64 EbmlFloat::UpdateSize(bool bSaveDefault, bool bForceRender)
+uint64 EbmlFloat::UpdateSize(bool bKeepIntact, bool bForceRender)
 {
-	if (!bSaveDefault && IsDefaultValue())
+	if (!bKeepIntact && IsDefaultValue())
 		return 0;
 	return Size;
 }
@@ -124,14 +112,6 @@ uint64 EbmlFloat::ReadData(IOCallback & input, ScopeMode ReadFully)
 			Value = *((double *) &tmpp);
 			bValueIsSet = true;
 		}
-#if LIBEBML_SUPPORT_FLOAT80
-		else {
-			big_80bits TmpRead;
-			TmpRead.Eval(Buffer);
-			bValueIsSet = true;
-	//		float val = *((float *)&(int32(TmpRead)));
-		}
-#endif // LIBEBML_SUPPORT_FLOAT80
 	}
 
 	return Size;
