@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlString.cpp 639 2004-07-09 20:59:14Z mosu $
+	\version \$Id: EbmlString.cpp 1033 2005-01-10 22:49:42Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #include <cassert>
@@ -73,7 +73,7 @@ EbmlString::EbmlString(const EbmlString & ElementToClone)
 /*!
 	\todo handle exception on errors
 */
-uint32 EbmlString::RenderData(IOCallback & output, bool bForceRender, bool bSaveDefault)
+uint32 EbmlString::RenderData(IOCallback & output, bool bForceRender, bool bKeepIntact)
 {
 	uint32 Result;
 	output.writeFully(Value.c_str(), Value.length());
@@ -106,9 +106,9 @@ EbmlString & EbmlString::operator=(const std::string NewString)
 	return *this;
 }
 
-uint64 EbmlString::UpdateSize(bool bSaveDefault, bool bForceRender)
+uint64 EbmlString::UpdateSize(bool bKeepIntact, bool bForceRender)
 {
-	if (!bSaveDefault && IsDefaultValue())
+	if (!bKeepIntact && IsDefaultValue())
 		return 0;
 
 	if (Value.length() < DefaultSize) {
