@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlVoid.cpp 639 2004-07-09 20:59:14Z mosu $
+	\version \$Id: EbmlVoid.cpp 1033 2005-01-10 22:49:42Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #include "ebml/EbmlVoid.h"
@@ -46,7 +46,7 @@ EbmlVoid::EbmlVoid()
 	bValueIsSet = true;
 }
 
-uint32 EbmlVoid::RenderData(IOCallback & output, bool bForceRender, bool bSaveDefault)
+uint32 EbmlVoid::RenderData(IOCallback & output, bool bForceRender, bool bKeepIntact)
 {
 	// write dummy data by 4KB chunks
 	static binary DummyBuf[4*1024];
@@ -61,9 +61,9 @@ uint32 EbmlVoid::RenderData(IOCallback & output, bool bForceRender, bool bSaveDe
 	return Size;
 }
 
-uint64 EbmlVoid::ReplaceWith(EbmlElement & EltToReplaceWith, IOCallback & output, bool ComeBackAfterward, bool bSaveDefault)
+uint64 EbmlVoid::ReplaceWith(EbmlElement & EltToReplaceWith, IOCallback & output, bool ComeBackAfterward, bool bKeepIntact)
 {
-	EltToReplaceWith.UpdateSize(bSaveDefault);
+	EltToReplaceWith.UpdateSize(bKeepIntact);
 	if (HeadSize() + Size < EltToReplaceWith.GetSize() + EltToReplaceWith.HeadSize()) {
 		// the element can't be written here !
 		return 0;
@@ -76,7 +76,7 @@ uint64 EbmlVoid::ReplaceWith(EbmlElement & EltToReplaceWith, IOCallback & output
 	uint64 CurrentPosition = output.getFilePointer();
 
 	output.setFilePointer(GetElementPosition());
-	EltToReplaceWith.Render(output, bSaveDefault);
+	EltToReplaceWith.Render(output, bKeepIntact);
 
 	if (HeadSize() + Size - EltToReplaceWith.GetSize() - EltToReplaceWith.HeadSize() > 1) {
 	  // fill the rest with another void element
@@ -88,7 +88,7 @@ uint64 EbmlVoid::ReplaceWith(EbmlElement & EltToReplaceWith, IOCallback & output
 	  if (HeadBefore != HeadAfter) {
 	    aTmp.SetSizeLength(CodedSizeLength(aTmp.Size, aTmp.SizeLength) - (HeadAfter - HeadBefore));
 	  }
-	  aTmp.RenderHead(output, false, bSaveDefault); // the rest of the data is not rewritten
+	  aTmp.RenderHead(output, false, bKeepIntact); // the rest of the data is not rewritten
 	}
 
 	if (ComeBackAfterward) {
@@ -98,9 +98,9 @@ uint64 EbmlVoid::ReplaceWith(EbmlElement & EltToReplaceWith, IOCallback & output
 	return Size + HeadSize();
 }
 
-uint64 EbmlVoid::Overwrite(const EbmlElement & EltToVoid, IOCallback & output, bool ComeBackAfterward, bool bSaveDefault)
+uint64 EbmlVoid::Overwrite(const EbmlElement & EltToVoid, IOCallback & output, bool ComeBackAfterward, bool bKeepIntact)
 {
-//	EltToVoid.UpdateSize(bSaveDefault);
+//	EltToVoid.UpdateSize(bKeepIntact);
 	if (EltToVoid.GetElementPosition() == 0) {
 		// this element has never been written
 		return 0;
@@ -126,7 +126,7 @@ uint64 EbmlVoid::Overwrite(const EbmlElement & EltToVoid, IOCallback & output, b
 	}
 
 	if (Size != 0) {
-		RenderHead(output, false, bSaveDefault); // the rest of the data is not rewritten
+		RenderHead(output, false, bKeepIntact); // the rest of the data is not rewritten
 	}
 
 	if (ComeBackAfterward) {
